@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 1170 2021-07-24 05:36:21Z Casey $
+# $Id: __init__.py 1266 2021-11-28 07:09:22Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $ (last)
-# $Date: 2021-07-24 13:36:21 +0800 (Sat, 24 Jul 2021) $
-# $Revision: 1170 $
+# $Author: Lavender $ (last)
+# $Date: 2021-11-28 15:09:22 +0800 (週日, 28 十一月 2021) $
+# $Revision: 1266 $
 
 import os
 import sys
@@ -196,6 +196,25 @@ def getOrCreateKey(username, keyPath=os.path.join("Keys")):
 def record(func, c, *args, **kwargs):
     rt = None
     try:
+        if not hasattr(c, 'recordLogs'):
+            # 沒有連到遠端的指令，EX: python Deploy.py mode stage
+            def _recordLogs():
+                # 因為沒有連遠端，不用記 log
+                pass
+            c.recordLogs = _recordLogs
+        if not hasattr(c, 'addLog'):
+            # 沒有連到遠端的指令，EX: python Deploy.py mode stage
+            def _addLog(msg):
+                # 因為沒有連遠端，直接把 log print 出來
+                cprint(
+                    colored(
+                        msg,
+                        "white"
+                    )
+                )
+            c.addLog = _addLog
+            
+        # 執行指令
         rt = func(c, *args, **kwargs)
     except Exception as e:
         cprint(
@@ -208,7 +227,7 @@ def record(func, c, *args, **kwargs):
         raise
     finally:
         c.recordLogs()
-
+       
     return rt
 
 # patch
